# Integration Methods

## CPU-based Methods

```{eval-rst}
.. module:: scembed.methods
.. currentmodule:: scembed

.. autosummary::
    :toctree: ../generated

    methods.HVGMethod
    methods.LIGERMethod
    methods.PrecomputedEmbeddingMethod
    methods.ScanoramaMethod
```

## GPU-based Methods

```{eval-rst}
.. module:: scembed.methods
.. currentmodule:: scembed

.. autosummary::
    :toctree: ../generated

    methods.HarmonyMethod
    methods.ResolVIMethod
    methods.scANVIMethod
    methods.scPoliMethod
    methods.scVIMethod
    methods.scVIVAMethod
```
